@@ -15,6 +15,7 @@
 import time
 
 import netaddr
+from neutron.i18n import _LE, _LW
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 import requests
@@ -89,7 +90,7 @@ class CsrRestClient(object):
         if method == 'POST' and self.status == requests.codes.CREATED:
             return response.headers.get('location', '')
         if self.status >= requests.codes.BAD_REQUEST and response.content:
-            if b'error-code' in response.content:
+            if 'error-code' in response.content:
                 content = jsonutils.loads(response.content)
                 LOG.debug("Error response content %s", content)
                 return content
@@ -110,8 +111,8 @@ class CsrRestClient(object):
         except (r_exc.Timeout, r_exc.SSLError) as te:
             # Should never see SSLError, unless requests package is old (<2.0)
             timeout_val = 0.0 if self.timeout is None else self.timeout
-            LOG.warning("%(method)s: Request timeout%(ssl)s "
-                        "(%(timeout).3f sec) for CSR(%(host)s)",
+            LOG.warning(_LW("%(method)s: Request timeout%(ssl)s "
+                            "(%(timeout).3f sec) for CSR(%(host)s)"),
                         {'method': method,
                          'timeout': timeout_val,
                          'ssl': '(SSLError)'
@@ -119,13 +120,13 @@ class CsrRestClient(object):
                          'host': self.host})
             self.status = requests.codes.REQUEST_TIMEOUT
         except r_exc.ConnectionError:
-            LOG.exception("%(method)s: Unable to connect to "
-                          "CSR(%(host)s)",
+            LOG.exception(_LE("%(method)s: Unable to connect to "
+                              "CSR(%(host)s)"),
                           {'method': method, 'host': self.host})
             self.status = requests.codes.NOT_FOUND
         except Exception as e:
-            LOG.error("%(method)s: Unexpected error for CSR (%(host)s): "
-                      "%(error)s",
+            LOG.error(_LE("%(method)s: Unexpected error for CSR (%(host)s): "
+                          "%(error)s"),
                       {'method': method, 'host': self.host, 'error': e})
             self.status = requests.codes.INTERNAL_SERVER_ERROR
         else:
@@ -154,7 +155,7 @@ class CsrRestClient(object):
             self.token = response['token-id']
             LOG.debug("Successfully authenticated with CSR %s", self.host)
             return True
-        LOG.error("Failed authentication with CSR %(host)s [%(status)s]",
+        LOG.error(_LE("Failed authentication with CSR %(host)s [%(status)s]"),
                   {'host': self.host, 'status': self.status})
 
     def _do_request(self, method, resource, payload=None, more_headers=None,
@@ -189,7 +190,7 @@ class CsrRestClient(object):
                                      headers=headers)
         if self.status != requests.codes.REQUEST_TIMEOUT:
             return response
-        LOG.error("%(method)s: Request timeout for CSR(%(host)s)",
+        LOG.error(_LE("%(method)s: Request timeout for CSR(%(host)s)"),
                   {'method': method, 'host': self.host})
 
     def get_request(self, resource, full_url=False):
