@@ -19,13 +19,13 @@ from neutron.common import exceptions
 from neutron.common import rpc as n_rpc
 from neutron import context as ctx
 from neutron.i18n import _LE, _LI, _LW
+from neutron.openstack.common import loopingcall
 from neutron.plugins.common import constants
 from neutron.plugins.common import utils as plugin_utils
 from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
-from oslo_service import loopingcall
 
 from neutron_vpnaas.services.vpn.common import topics
 from neutron_vpnaas.services.vpn import device_drivers
@@ -235,7 +235,7 @@ class CiscoCsrIPsecDriver(device_drivers.DeviceDriver):
         """Remove connections that are not known by service driver."""
         service_count = 0
         connection_count = 0
-        for vpn_service_id, vpn_service in list(self.service_state.items()):
+        for vpn_service_id, vpn_service in self.service_state.items():
             dirty = [c_id for c_id, c in vpn_service.conn_state.items()
                      if c.is_dirty]
             vpn_service.connections_removed = len(dirty) > 0
