@@ -14,15 +14,13 @@
 #    under the License.
 
 import os
+import shutil
 
 from oslo_config import cfg
 from oslo_log import log as logging
 
 from neutron.agent.linux import ip_lib
-from neutron.agent.linux import utils
-from neutron_lib import constants
-
-from neutron_vpnaas._i18n import _
+from neutron.plugins.common import constants
 from neutron_vpnaas.services.vpn.device_drivers import ipsec
 
 LOG = logging.getLogger(__name__)
@@ -57,6 +55,8 @@ strongswan_opts = [
 ]
 cfg.CONF.register_opts(strongswan_opts, 'strongswan')
 
+NS_WRAPPER = 'neutron-vpn-netns-wrapper'
+
 
 class StrongSwanProcess(ipsec.BaseSwanProcess):
 
@@ -64,45 +64,20 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
     # CONNECTING means route created, connection tunnel is negotiating.
     # INSTALLED means route created,
     #           also connection tunnel installed. (traffic can pass)
-
-    DIALECT_MAP = dict(ipsec.BaseSwanProcess.DIALECT_MAP)
-
     STATUS_DICT = {
         'ROUTED': constants.DOWN,
         'CONNECTING': constants.DOWN,
         'INSTALLED': constants.ACTIVE
     }
-    STATUS_RE = r'([a-f0-9\-]+).* (ROUTED|CONNECTING|INSTALLED)'
+    STATUS_RE = '([a-f0-9\-]+).* (ROUTED|CONNECTING|INSTALLED)'
     STATUS_NOT_RUNNING_RE = 'Command:.*ipsec.*status.*Exit code: [1|3] '
 
     def __init__(self, conf, process_id, vpnservice, namespace):
         self.DIALECT_MAP['v1'] = 'ikev1'
         self.DIALECT_MAP['v2'] = 'ikev2'
-        self.DIALECT_MAP['sha256'] = 'sha256'
-        self._strongswan_piddir = self._get_strongswan_piddir()
-        self._rootwrap_cfg = self._get_rootwrap_config()
-        LOG.debug("strongswan piddir is '%s'", (self._strongswan_piddir))
         super(StrongSwanProcess, self).__init__(conf, process_id,
                                                 vpnservice, namespace)
 
-    def _get_strongswan_piddir(self):
-        return utils.execute(
-            cmd=[self.binary, "--piddir"], run_as_root=True).strip()
-
-    def _check_status_line(self, line):
-        """Parse a line and search for status information.
-
-        If a given line contains status information for a connection,
-        extract the status and mark the connection as ACTIVE or DOWN
-        according to the STATUS_MAP.
-        """
-        m = self.STATUS_PATTERN.search(line)
-        if m:
-            connection_id = m.group(1)
-            status = self.STATUS_MAP[m.group(2)]
-            return connection_id, status
-        return None, None
-
     def _execute(self, cmd, check_exit_code=True, extra_ok_codes=None):
         """Execute command on namespace.
 
@@ -110,24 +85,18 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
         The namespace wrapper will bind /etc/ and /var/run
         """
         ip_wrapper = ip_lib.IPWrapper(namespace=self.namespace)
-        ns_wrapper = self.get_ns_wrapper()
         return ip_wrapper.netns.execute(
-            [ns_wrapper,
-             '--mount_paths=/etc:%s/etc,%s:%s/var/run' % (
-                 self.config_dir, self._strongswan_piddir, self.config_dir),
-             ('--rootwrap_config=%s' % self._rootwrap_cfg
-                 if self._rootwrap_cfg else ''),
+            [NS_WRAPPER,
+             '--mount_paths=/etc:%s/etc,/var/run:%s/var/run' % (
+                 self.config_dir, self.config_dir),
              '--cmd=%s' % ','.join(cmd)],
             check_exit_code=check_exit_code,
             extra_ok_codes=extra_ok_codes)
 
     def copy_and_overwrite(self, from_path, to_path):
-        # NOTE(toabctl): the agent may run as non-root user, so rm/copy as root
         if os.path.exists(to_path):
-            utils.execute(
-                cmd=["rm", "-rf", to_path], run_as_root=True)
-        utils.execute(
-            cmd=["cp", "-a", from_path, to_path], run_as_root=True)
+            shutil.rmtree(to_path)
+        shutil.copytree(from_path, to_path)
 
     def ensure_configs(self):
         """Generate config files which are needed for StrongSwan.
@@ -158,20 +127,8 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
 
     def restart(self):
         """Restart the process."""
-        self.reload_secrets()
         self.reload()
 
-    def reload_secrets(self):
-        """Reload the ipsec.secrets file.
-
-        Flushes and rereads all secrets defined in ipsec.secrets. This needs
-        to be done each time when a new site connection is associated with
-        a VPN service which already hosts a site connection - 'ipsec reload'
-        does not reload the secrets and new connections will not authenticate
-        properly.
-        """
-        self._execute([self.binary, 'rereadsecrets'])
-
     def reload(self):
         """Reload the process.
 
@@ -191,10 +148,6 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
         if not self.namespace:
             return
         self._execute([self.binary, 'start'])
-        # initiate ipsec connection
-        for ipsec_site_conn in self.vpnservice['ipsec_site_connections']:
-            self._execute([self.binary, 'stroke', 'up-nb',
-                           ipsec_site_conn['id']])
 
     def stop(self):
         self._execute([self.binary, 'stop'])
