@@ -14,20 +14,21 @@
 #    under the License.
 
 import collections
+import logging
+
+import oslo_messaging as messaging
 import pprint
+import six
 
 from networking_brocade.vyatta.common import exceptions as v_exc
 from networking_brocade.vyatta.common import vrouter_config
 from networking_brocade.vyatta.vpn import config as vyatta_vpn_config
 from neutron.common import rpc as n_rpc
-from neutron_lib import context as n_ctx
-from oslo_config import cfg
-from oslo_log import log as logging
-import oslo_messaging as messaging
-from oslo_service import loopingcall
-from oslo_service import periodic_task
+from neutron import context as n_ctx
+from neutron.i18n import _LE, _LW
+from neutron.openstack.common import loopingcall
+from neutron.openstack.common import periodic_task
 
-from neutron_vpnaas._i18n import _
 from neutron_vpnaas.services.vpn.common import topics
 from neutron_vpnaas.services.vpn import device_drivers
 
@@ -75,8 +76,8 @@ class NeutronServerAPI(object):
                 for conn in svc[_KEY_CONNECTIONS]:
                     vyatta_vpn_config.validate_svc_connection(conn)
             except v_exc.InvalidVPNServiceError:
-                LOG.error('Invalid or incomplete VPN service data: '
-                          'id={id}'.format(id=svc.get('id')))
+                LOG.error(_LE('Invalid or incomplete VPN service data: '
+                              'id={id}').format(id=svc.get('id')))
                 continue
             vpn_services.append(svc)
 
@@ -100,7 +101,7 @@ class VyattaIPSecDriver(device_drivers.DeviceDriver):
         self.host = host
 
         # register RPC endpoint
-        conn = n_rpc.create_connection()
+        conn = n_rpc.create_connection(new=True)
         node_topic = '%s.%s' % (topics.BROCADE_IPSEC_AGENT_TOPIC,
                                 self.host)
 
@@ -108,7 +109,7 @@ class VyattaIPSecDriver(device_drivers.DeviceDriver):
         conn.create_consumer(node_topic, endpoints, fanout=False)
         conn.consume_in_threads()
 
-        # initialize agent to server RPC link
+        # initialize agent ot server RPC link
         self.server_api = NeutronServerAPI(
             topics.BROCADE_IPSEC_DRIVER_TOPIC)
 
@@ -256,7 +257,7 @@ class VyattaIPSecDriver(device_drivers.DeviceDriver):
 
 class _VyattaPeriodicTasks(periodic_task.PeriodicTasks):
     def __init__(self, driver):
-        super(_VyattaPeriodicTasks, self).__init__(cfg.CONF)
+        super(_VyattaPeriodicTasks, self).__init__()
         self.driver = driver
 
     def __call__(self):
@@ -273,15 +274,15 @@ class _VyattaPeriodicTasks(periodic_task.PeriodicTasks):
 
         status = list()
 
-        for router_id, svc_set in svc_by_vrouter.items():
+        for router_id, svc_set in six.iteritems(svc_by_vrouter):
             vrouter = self.driver.vpn_service.get_router_client(router_id)
             resources = self.driver.get_router_resources(router_id)
 
             try:
                 ipsec_sa = vrouter.get_vpn_ipsec_sa()
             except v_exc.VRouterOperationError as e:
-                LOG.warning('Failed to fetch tunnel stats from router '
-                            '{0}: {1}'.format(router_id, unicode(e)))
+                LOG.warn(_LW('Failed to fetch tunnel stats from router '
+                             '{0}: {1}').format(router_id, unicode(e)))
                 continue
 
             conn_ok = vyatta_vpn_config.parse_vpn_connections(
