@@ -14,11 +14,10 @@
 #    under the License.
 
 import copy
-from unittest import mock
-
+import mock
+from neutron.openstack.common import uuidutils
+from neutron.plugins.common import constants
 from neutron.tests.unit.api.v2 import test_base as test_api_v2
-from neutron_lib.plugins import constants as nconstants
-from oslo_utils import uuidutils
 from webob import exc
 
 from neutron_vpnaas.extensions import vpnaas
@@ -35,11 +34,11 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         super(VpnaasExtensionTestCase, self).setUp()
         plural_mappings = {'ipsecpolicy': 'ipsecpolicies',
                            'ikepolicy': 'ikepolicies',
-                           'ipsec_site_connection': 'ipsec-site-connections',
-                           'endpoint_group': 'endpoint-groups'}
-        self.setup_extension(
-            'neutron_vpnaas.extensions.vpnaas.VPNPluginBase', nconstants.VPN,
-            vpnaas.Vpnaas, 'vpn', plural_mappings=plural_mappings,
+                           'ipsec_site_connection': 'ipsec-site-connections'}
+        self._setUpExtension(
+            'neutron_vpnaas.extensions.vpnaas.VPNPluginBase', constants.VPN,
+            vpnaas.RESOURCE_ATTRIBUTE_MAP, vpnaas.Vpnaas,
+            'vpn', plural_mappings=plural_mappings,
             use_quota=True)
 
     def test_ikepolicy_create(self):
@@ -65,40 +64,12 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         res = self.api.post(_get_path('vpn/ikepolicies', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/%s' % self.fmt)
-        self.assertEqual(1, instance.create_ikepolicy.call_count)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
+        instance.create_ikepolicy.assert_called_with(mock.ANY,
+                                                     ikepolicy=data)
+        self.assertEqual(res.status_int, exc.HTTPCreated.code)
         res = self.deserialize(res)
         self.assertIn('ikepolicy', res)
-        self.assertDictSupersetOf(return_value, res['ikepolicy'])
-
-    def test_ikepolicy_create_with_aggressive_mode(self):
-        """Test case to create an ikepolicy with agressive mode."""
-        ikepolicy_id = _uuid()
-        data = {'ikepolicy': {'name': 'ikepolicy1',
-                              'description': 'myikepolicy1',
-                              'auth_algorithm': 'sha1',
-                              'encryption_algorithm': 'aes-128',
-                              'phase1_negotiation_mode': 'aggressive',
-                              'lifetime': {
-                                  'units': 'seconds',
-                                  'value': 3600},
-                              'ike_version': 'v1',
-                              'pfs': 'group5',
-                              'tenant_id': _uuid()}}
-
-        return_value = copy.copy(data['ikepolicy'])
-        return_value.update({'id': ikepolicy_id})
-
-        instance = self.plugin.return_value
-        instance.create_ikepolicy.return_value = return_value
-        res = self.api.post(_get_path('vpn/ikepolicies', fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt)
-        self.assertEqual(1, instance.create_ikepolicy.call_count)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('ikepolicy', res)
-        self.assertDictSupersetOf(return_value, res['ikepolicy'])
+        self.assertEqual(res['ikepolicy'], return_value)
 
     def test_ikepolicy_list(self):
         """Test case to list all ikepolicies."""
@@ -118,7 +89,7 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_ikepolicies.assert_called_with(mock.ANY,
                                                     fields=mock.ANY,
                                                     filters=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
 
     def test_ikepolicy_update(self):
         """Test case to update an ikepolicy."""
@@ -146,43 +117,10 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
 
         instance.update_ikepolicy.assert_called_with(mock.ANY, ikepolicy_id,
                                                      ikepolicy=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('ikepolicy', res)
-        self.assertEqual(return_value, res['ikepolicy'])
-
-    def test_ikepolicy_update_with_aggressive_mode(self):
-        """Test case to update an ikepolicy with aggressive mode."""
-        ikepolicy_id = _uuid()
-        update_data = {'ikepolicy':
-                       {'name': 'ikepolicy1',
-                        'phase1_negotiation_mode': 'aggressive',
-                        'encryption_algorithm': 'aes-256'}}
-        return_value = {'name': 'ikepolicy1',
-                        'auth_algorithm': 'sha1',
-                        'encryption_algorithm': 'aes-256',
-                        'phase1_negotiation_mode': 'aggressive',
-                        'lifetime': {
-                            'units': 'seconds',
-                            'value': 3600},
-                        'ike_version': 'v1',
-                        'pfs': 'group5',
-                        'tenant_id': _uuid(),
-                        'id': ikepolicy_id}
-
-        instance = self.plugin.return_value
-        instance.update_ikepolicy.return_value = return_value
-
-        res = self.api.put(_get_path('vpn/ikepolicies', id=ikepolicy_id,
-                                     fmt=self.fmt),
-                           self.serialize(update_data))
-
-        instance.update_ikepolicy.assert_called_with(mock.ANY, ikepolicy_id,
-                                                     ikepolicy=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('ikepolicy', res)
-        self.assertEqual(return_value, res['ikepolicy'])
+        self.assertEqual(res['ikepolicy'], return_value)
 
     def test_ikepolicy_get(self):
         """Test case to get or show an ikepolicy."""
@@ -208,10 +146,10 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_ikepolicy.assert_called_with(mock.ANY,
                                                   ikepolicy_id,
                                                   fields=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('ikepolicy', res)
-        self.assertEqual(return_value, res['ikepolicy'])
+        self.assertEqual(res['ikepolicy'], return_value)
 
     def test_ikepolicy_delete(self):
         """Test case to delete an ikepolicy."""
@@ -239,11 +177,12 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         res = self.api.post(_get_path('vpn/ipsecpolicies', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/%s' % self.fmt)
-        self.assertEqual(1, instance.create_ipsecpolicy.call_count)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
+        instance.create_ipsecpolicy.assert_called_with(mock.ANY,
+                                                       ipsecpolicy=data)
+        self.assertEqual(res.status_int, exc.HTTPCreated.code)
         res = self.deserialize(res)
         self.assertIn('ipsecpolicy', res)
-        self.assertDictSupersetOf(return_value, res['ipsecpolicy'])
+        self.assertEqual(res['ipsecpolicy'], return_value)
 
     def test_ipsecpolicy_list(self):
         """Test case to list an ipsecpolicy."""
@@ -262,7 +201,7 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_ipsecpolicies.assert_called_with(mock.ANY,
                                                       fields=mock.ANY,
                                                       filters=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
 
     def test_ipsecpolicy_update(self):
         """Test case to update an ipsecpolicy."""
@@ -292,10 +231,10 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.update_ipsecpolicy.assert_called_with(mock.ANY,
                                                        ipsecpolicy_id,
                                                        ipsecpolicy=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('ipsecpolicy', res)
-        self.assertEqual(return_value, res['ipsecpolicy'])
+        self.assertEqual(res['ipsecpolicy'], return_value)
 
     def test_ipsecpolicy_get(self):
         """Test case to get or show an ipsecpolicy."""
@@ -322,58 +261,38 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_ipsecpolicy.assert_called_with(mock.ANY,
                                                     ipsecpolicy_id,
                                                     fields=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('ipsecpolicy', res)
-        self.assertEqual(return_value, res['ipsecpolicy'])
+        self.assertEqual(res['ipsecpolicy'], return_value)
 
     def test_ipsecpolicy_delete(self):
         """Test case to delete an ipsecpolicy."""
         self._test_entity_delete('ipsecpolicy')
 
-    def _test_vpnservice_create(self, more_args, defaulted_args):
-        """Helper to test VPN service creation.
-
-        Allows additional args to be specified for different test cases.
-        Includes expected args, for case where an optional args are not
-        specified and API applies defaults.
-        """
-
+    def test_vpnservice_create(self):
+        """Test case to create a vpnservice."""
+        vpnservice_id = _uuid()
         data = {'vpnservice': {'name': 'vpnservice1',
                                'description': 'descr_vpn1',
+                               'subnet_id': _uuid(),
                                'router_id': _uuid(),
                                'admin_state_up': True,
                                'tenant_id': _uuid()}}
-        data['vpnservice'].update(more_args)
-
-        # Add in any default values for args that were not provided
-        actual_args = copy.copy(data)
-        actual_args['vpnservice'].update(defaulted_args)
-
         return_value = copy.copy(data['vpnservice'])
-        return_value.update({'status': "ACTIVE", 'id': _uuid()})
-        return_value.update(defaulted_args)
+        return_value.update({'status': "ACTIVE", 'id': vpnservice_id})
+
         instance = self.plugin.return_value
         instance.create_vpnservice.return_value = return_value
-
         res = self.api.post(_get_path('vpn/vpnservices', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/%s' % self.fmt)
-        self.assertEqual(1, instance.create_vpnservice.call_count)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
+        instance.create_vpnservice.assert_called_with(mock.ANY,
+                                                      vpnservice=data)
+        self.assertEqual(res.status_int, exc.HTTPCreated.code)
         res = self.deserialize(res)
         self.assertIn('vpnservice', res)
-        self.assertDictSupersetOf(return_value, res['vpnservice'])
-
-    def test_vpnservice_create(self):
-        """Create VPN service using subnet (older API)."""
-        subnet = {'subnet_id': _uuid()}
-        self._test_vpnservice_create(more_args=subnet, defaulted_args={})
-
-    def test_vpnservice_create_no_subnet(self):
-        """Test case to create a vpnservice w/o subnet (newer API)."""
-        no_subnet = {'subnet_id': None}
-        self._test_vpnservice_create(more_args={}, defaulted_args=no_subnet)
+        self.assertEqual(res['vpnservice'], return_value)
 
     def test_vpnservice_list(self):
         """Test case to list all vpnservices."""
@@ -391,7 +310,7 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_vpnservices.assert_called_with(mock.ANY,
                                                     fields=mock.ANY,
                                                     filters=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
 
     def test_vpnservice_update(self):
         """Test case to update a vpnservice."""
@@ -416,10 +335,10 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.update_vpnservice.assert_called_with(mock.ANY,
                                                       vpnservice_id,
                                                       vpnservice=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('vpnservice', res)
-        self.assertEqual(return_value, res['vpnservice'])
+        self.assertEqual(res['vpnservice'], return_value)
 
     def test_vpnservice_get(self):
         """Test case to get or show a vpnservice."""
@@ -442,17 +361,17 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_vpnservice.assert_called_with(mock.ANY,
                                                    vpnservice_id,
                                                    fields=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('vpnservice', res)
-        self.assertEqual(return_value, res['vpnservice'])
+        self.assertEqual(res['vpnservice'], return_value)
 
     def test_vpnservice_delete(self):
         """Test case to delete a vpnservice."""
         self._test_entity_delete('vpnservice')
 
-    def _test_ipsec_site_connection_create(self, more_args, defaulted_args):
-        """Helper to test creating IPSec connection."""
+    def test_ipsec_site_connection_create(self):
+        """Test case to create a ipsec_site_connection."""
         ipsecsite_con_id = _uuid()
         ikepolicy_id = _uuid()
         ipsecpolicy_id = _uuid()
@@ -461,6 +380,8 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
                                       'description': 'Remote-connection1',
                                       'peer_address': '192.168.1.10',
                                       'peer_id': '192.168.1.10',
+                                      'peer_cidrs': ['192.168.2.0/24',
+                                                     '192.168.3.0/24'],
                                       'mtu': 1500,
                                       'psk': 'abcd',
                                       'initiator': 'bi-directional',
@@ -474,73 +395,22 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
                                       'admin_state_up': True,
                                       'tenant_id': _uuid()}
         }
-        data['ipsec_site_connection'].update(more_args)
-
-        # Add in any default values for args that were not provided
-        actual_args = copy.copy(data)
-        actual_args['ipsec_site_connection'].update(defaulted_args)
-
         return_value = copy.copy(data['ipsec_site_connection'])
         return_value.update({'status': "ACTIVE", 'id': ipsecsite_con_id})
-        return_value.update(defaulted_args)
+
         instance = self.plugin.return_value
         instance.create_ipsec_site_connection.return_value = return_value
-
         res = self.api.post(_get_path('vpn/ipsec-site-connections',
                                       fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/%s' % self.fmt)
-        self.assertEqual(1, instance.create_ipsec_site_connection.call_count)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
+        instance.create_ipsec_site_connection.assert_called_with(
+            mock.ANY, ipsec_site_connection=data
+        )
+        self.assertEqual(res.status_int, exc.HTTPCreated.code)
         res = self.deserialize(res)
         self.assertIn('ipsec_site_connection', res)
-        self.assertDictSupersetOf(return_value, res['ipsec_site_connection'])
-
-    def test_ipsec_site_connection_create(self):
-        """Create an IPSec connection with peer CIDRs (old API)."""
-        more_args = {'peer_cidrs': ['192.168.2.0/24', '192.168.3.0/24'],
-                     'local_id': ''}
-        no_endpoint_groups = {'local_ep_group_id': None,
-                              'peer_ep_group_id': None}
-        self._test_ipsec_site_connection_create(
-            more_args=more_args, defaulted_args=no_endpoint_groups)
-
-    def test_ipsec_site_connection_create_with_endpoints(self):
-        """Create an IPSec connection with endpoint groups (new API)."""
-        more_args = {'local_ep_group_id': _uuid(),
-                     'peer_ep_group_id': _uuid(),
-                     'local_id': ''}
-        no_peer_cidrs = {'peer_cidrs': []}
-        self._test_ipsec_site_connection_create(more_args=more_args,
-                                                defaulted_args=no_peer_cidrs)
-
-    def test_ipsec_site_connection_create_with_invalid_cidr_format(self):
-        peer_cidrs = ['192.168.2.0/24', '10/8']
-        data = {
-            'ipsec_site_connection': {'name': 'connection1',
-                                      'description': 'Remote-connection1',
-                                      'peer_address': '192.168.1.10',
-                                      'peer_id': '192.168.1.10',
-                                      'peer_cidrs': peer_cidrs,
-                                      'mtu': 1500,
-                                      'psk': 'abcd',
-                                      'initiator': 'bi-directional',
-                                      'dpd': {
-                                          'action': 'hold',
-                                          'interval': 30,
-                                          'timeout': 120},
-                                      'ikepolicy_id': _uuid(),
-                                      'ipsecpolicy_id': _uuid(),
-                                      'vpnservice_id': _uuid(),
-                                      'admin_state_up': True,
-                                      'tenant_id': _uuid()}
-        }
-        res = self.api.post(_get_path('vpn/ipsec-site-connections',
-                                      fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt,
-                            expect_errors=True)
-        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
+        self.assertEqual(res['ipsec_site_connection'], return_value)
 
     def test_ipsec_site_connection_list(self):
         """Test case to list all ipsec_site_connections."""
@@ -550,8 +420,6 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
                          'peer_cidrs': ['192.168.2.0/24', '192.168.3.0/24'],
                          'route_mode': 'static',
                          'auth_mode': 'psk',
-                         'local_ep_group_id': None,
-                         'peer_ep_group_id': None,
                          'tenant_id': _uuid(),
                          'status': 'ACTIVE',
                          'id': ipsecsite_con_id}]
@@ -565,7 +433,7 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_ipsec_site_connections.assert_called_with(
             mock.ANY, fields=mock.ANY, filters=mock.ANY
         )
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
 
     def test_ipsec_site_connection_update(self):
         """Test case to update a ipsec_site_connection."""
@@ -587,8 +455,6 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
                         'ipsecpolicy_id': _uuid(),
                         'vpnservice_id': _uuid(),
                         'admin_state_up': False,
-                        'local_ep_group_id': None,
-                        'peer_ep_group_id': None,
                         'tenant_id': _uuid(),
                         'status': 'ACTIVE',
                         'id': ipsecsite_con_id}
@@ -605,10 +471,10 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
             mock.ANY, ipsecsite_con_id, ipsec_site_connection=update_data
         )
 
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('ipsec_site_connection', res)
-        self.assertEqual(return_value, res['ipsec_site_connection'])
+        self.assertEqual(res['ipsec_site_connection'], return_value)
 
     def test_ipsec_site_connection_get(self):
         """Test case to get or show a ipsec_site_connection."""
@@ -631,8 +497,6 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
                         'vpnservice_id': _uuid(),
                         'admin_state_up': True,
                         'tenant_id': _uuid(),
-                        'local_ep_group_id': None,
-                        'peer_ep_group_id': None,
                         'status': 'ACTIVE',
                         'id': ipsecsite_con_id}
 
@@ -646,10 +510,10 @@ class VpnaasExtensionTestCase(base.ExtensionTestCase):
         instance.get_ipsec_site_connection.assert_called_with(
             mock.ANY, ipsecsite_con_id, fields=mock.ANY
         )
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
+        self.assertEqual(res.status_int, exc.HTTPOk.code)
         res = self.deserialize(res)
         self.assertIn('ipsec_site_connection', res)
-        self.assertEqual(return_value, res['ipsec_site_connection'])
+        self.assertEqual(res['ipsec_site_connection'], return_value)
 
     def test_ipsec_site_connection_delete(self):
         """Test case to delete a ipsec_site_connection."""
