@@ -836,7 +836,9 @@ class TestLibreSwanProcess(base.BaseTestCase):
             self.assertTrue(self.ipsec_process._process_running())
             self.assertTrue(log_mock.called)
 
-    def test_ensure_configs(self):
+    @mock.patch('os.remove')
+    @mock.patch('os.path.exists', return_value=True)
+    def test_ensure_configs_on_restart(self, exists_mock, remove_mock):
         ipsec_driver.OpenSwanProcess.ensure_configs = mock.Mock()
         with mock.patch.object(self.ipsec_process, '_execute') as fake_execute:
             self.ipsec_process.ensure_configs()
@@ -849,6 +851,29 @@ class TestLibreSwanProcess(base.BaseTestCase):
                                    self.ipsec_process.etc_dir])]
             fake_execute.assert_has_calls(expected)
             self.assertEqual(3, fake_execute.call_count)
+            self.assertTrue(exists_mock.called)
+            self.assertTrue(remove_mock.called)
+
+    @mock.patch('os.remove')
+    @mock.patch('os.path.exists', return_value=False)
+    def test_ensure_configs(self, exists_mock, remove_mock):
+        ipsec_driver.OpenSwanProcess.ensure_configs = mock.Mock()
+        with mock.patch.object(self.ipsec_process, '_execute') as fake_execute:
+            self.ipsec_process.ensure_configs()
+            expected = [mock.call(['chown', '--from=%s' % os.getuid(),
+                                   'root:root',
+                                   self.ipsec_process._get_config_filename(
+                                       'ipsec.secrets')]),
+                        mock.call(['ipsec', '_stackmanager', 'start']),
+                        mock.call(['ipsec', 'checknss',
+                                   self.ipsec_process.etc_dir])]
+            fake_execute.assert_has_calls(expected)
+            self.assertEqual(3, fake_execute.call_count)
+            self.assertTrue(exists_mock.called)
+            self.assertFalse(remove_mock.called)
+
+        exists_mock.reset_mock()
+        remove_mock.reset_mock()
 
         with mock.patch.object(self.ipsec_process, '_execute') as fake_execute:
             fake_execute.side_effect = [None, None, RuntimeError, None]
@@ -864,6 +889,8 @@ class TestLibreSwanProcess(base.BaseTestCase):
                                    self.ipsec_process.etc_dir])]
             fake_execute.assert_has_calls(expected)
             self.assertEqual(4, fake_execute.call_count)
+            self.assertTrue(exists_mock.called)
+            self.assertFalse(remove_mock.called)
 
 
 class IPsecStrongswanDeviceDriverLegacy(IPSecDeviceLegacy):
